"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_os_1 = __importDefault(require("node:os"));
const ws_1 = __importDefault(require("ws"));
class WebSocketClient {
    autoReconnectInterval = 5 * 1000; // ms
    ev;
    url;
    instance;
    constructor(ev) {
        this.ev = ev;
    }
    open(url, forceClose) {
        this.url = url;
        this.instance = new ws_1.default(this.url);
        this.instance.on("open", () => {
            this.onopen();
        });
        this.instance.on("message", (data) => {
            this.onmessage(data);
        });
        this.instance.on("close", (e) => {
            if (forceClose)
                return;
            if (e.code === 1000) {
                console.log("WebSocket: closed");
            }
            else {
                this.reconnect(e);
            }
            this.onclose();
        });
        this.instance.on("error", (e) => {
            if (e.code === node_os_1.default.constants.errno.ECONNREFUSED) {
                this.reconnect(e);
            }
            else {
                this.onerror(e);
            }
        });
    }
    send(data) {
        try {
            this.instance?.send(data);
        }
        catch (e) {
            this.instance?.emit("error", e);
        }
    }
    reconnect(e) {
        console.log(`WebSocketClient: retry in ${this.autoReconnectInterval}ms`, e);
        this.instance?.removeAllListeners();
        setTimeout(() => {
            if (this.url)
                this.open(this.url);
        }, this.autoReconnectInterval);
    }
    onopen() {
        this.ev.emit("open");
    }
    onmessage(data) {
        this.ev.emit("message", data);
    }
    onerror(e) {
        this.ev.emit("error", e);
    }
    onclose() {
        this.ev.emit("close");
    }
}
exports.default = WebSocketClient;
