"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ws_1 = require("ws");
const WebSocketHelper_1 = require("../WebSocketHelper");
const util_1 = require("../util");
module.exports = (RED) => {
    const ev = new ws_1.EventEmitter();
    (0, WebSocketHelper_1.open)(RED, ev, "/mobile/serial");
    function RedMobileSerialOpenNode(props) {
        RED.nodes.createNode(this, props);
        const options = {
            baudRate: props.baudRate,
            dataBits: props.dataBits,
            stopBits: props.stopBits,
            parity: props.parity,
            dtr: props.dtr,
            rts: props.rts,
        };
        this.on("input", (msg) => {
            const json = {
                id: this.id,
                method: "serial-open",
                payload: msg.payload,
                options: options,
            };
            (0, util_1.postRequest)(RED, this, msg, json);
        });
    }
    RED.nodes.registerType("serial-open", RedMobileSerialOpenNode);
    function RedMobileSerialCloseNode(props) {
        RED.nodes.createNode(this, props);
        this.on("input", (msg) => {
            const params = {
                id: this.id,
                method: "serial-close",
            };
            (0, util_1.getRequest)(RED, this, msg, params, 5000);
        });
    }
    RED.nodes.registerType("serial-close", RedMobileSerialCloseNode);
    function RedMobileSerialWriteNode(props) {
        RED.nodes.createNode(this, props);
        this.on("input", (msg) => {
            const json = {
                id: this.id,
                method: "serial-write",
                payload: props.data ? props.data : msg.payload,
                dataType: props.dataType,
            };
            if (json.payload) {
                (0, util_1.postRequest)(RED, this, msg, json);
            }
            else {
                this.error(RED._("serial-write.errors.payload"));
                this.status({
                    fill: "red",
                    shape: "ring",
                    text: RED._("serial-write.errors.payload"),
                });
            }
        });
    }
    RED.nodes.registerType("serial-write", RedMobileSerialWriteNode);
    function RedMobileSerialReadNode(props) {
        RED.nodes.createNode(this, props);
        ev.on("message", (data) => {
            const payload = JSON.parse(data).payload;
            if (payload) {
                this.send({ payload: payload });
            }
        });
    }
    RED.nodes.registerType("serial-read", RedMobileSerialReadNode);
};
