"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = DB;
const axios_1 = __importDefault(require("axios"));
const qs_1 = __importDefault(require("qs"));
const BASE_URL = "http://127.0.0.1";
const PATH = "/mobile";
let dbname;
let redSettings;
function DB(_settings, _dbname) {
    redSettings = _settings;
    dbname = _dbname;
}
DB.prototype.all = (id, sql, params, callback) => {
    const json = {
        id: id,
        method: "sqlite-all",
        dbname: dbname,
        payload: sql,
        params: params,
    };
    const config = generateConfig(json);
    axios_1.default
        .request(config)
        .then((res) => {
        callback(null, res.data);
    })
        .catch((err) => {
        callback(new Error(err.response.data));
    });
};
DB.prototype.exec = (id, sql, callback) => {
    const json = {
        id: id,
        method: "sqlite-exec",
        dbname: dbname,
        payload: sql,
    };
    const config = generateConfig(json);
    axios_1.default
        .request(config)
        .then(() => {
        callback(null);
    })
        .catch((err) => {
        callback(new Error(err.response.data));
    });
};
DB.prototype.loadExtension = (_, callback) => {
    callback(new Error("extension is not supported"));
};
DB.prototype.close = (id, done) => {
    const json = {
        id: id,
        method: "sqlite-close",
        dbname: dbname,
    };
    const config = generateConfig(json);
    axios_1.default
        .request(config)
        .then(() => {
        done();
    })
        .catch(() => {
        done();
    });
};
DB.prototype.delete = (id, callback) => {
    const json = {
        id: id,
        method: "sqlite-delete",
        dbname: dbname,
    };
    const config = generateConfig(json);
    axios_1.default
        .request(config)
        .then((res) => {
        callback(null, res.data);
    })
        .catch((err) => {
        callback(new Error(err.response.data));
    });
};
function generateConfig(json) {
    return {
        baseURL: `${BASE_URL}:${redSettings.redMobilePort}`,
        url: PATH,
        method: "post",
        data: qs_1.default.stringify(json),
        headers: {
            Authorization: `Bearer: ${redSettings.redMobileAccessKey}`,
            "Content-Type": "application/x-www-form-urlencoded",
        },
    };
}
