"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateGetConfig = generateGetConfig;
exports.sendSuccess = sendSuccess;
exports.sendError = sendError;
exports.generatePostConfig = generatePostConfig;
exports.postRequest = postRequest;
exports.getRequest = getRequest;
const axios_1 = __importDefault(require("axios"));
const qs_1 = __importDefault(require("qs"));
const BASE_URL = "http://127.0.0.1";
const PATH = "/mobile";
function generateGetConfig(RED, params, timeout) {
    return {
        baseURL: `${BASE_URL}:${RED.settings.redMobilePort}`,
        url: PATH,
        method: "get",
        headers: {
            "Content-Type": "application/json",
            Authorization: `Bearer: ${RED.settings.redMobileAccessKey}`,
        },
        params: params,
        timeout: timeout,
    };
}
function sendSuccess(node, msg, res) {
    if (res.data) {
        msg.payload = res.data;
    }
    node.send(msg);
    node.status({
        fill: "blue",
        shape: "dot",
        text: "success",
    });
}
function sendError(node, err) {
    const payload = err.response.data;
    node.error(payload);
    node.status({
        fill: "red",
        shape: "ring",
        text: payload,
    });
}
function generatePostConfig(RED) {
    return {
        baseURL: `${BASE_URL}:${RED.settings.redMobilePort}`,
        headers: {
            Authorization: `Bearer: ${RED.settings.redMobileAccessKey}`,
            "Content-Type": "application/x-www-form-urlencoded",
        },
    };
}
function postRequest(RED, node, msg, json) {
    axios_1.default
        .post(PATH, qs_1.default.stringify(json), generatePostConfig(RED))
        .then((res) => {
        sendSuccess(node, msg, res);
    })
        .catch((err) => {
        sendError(node, err);
    });
}
function getRequest(RED, node, msg, params, timeout) {
    axios_1.default
        .request(generateGetConfig(RED, params, timeout))
        .then((res) => {
        sendSuccess(node, msg, res);
    })
        .catch((err) => {
        sendError(node, err);
    });
}
