"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("../util");
module.exports = (RED) => {
    function RedMobileVolumeGetNode(props) {
        RED.nodes.createNode(this, props);
        this.on("input", (msg) => {
            const json = {
                id: this.id,
                method: "volume-get",
                payload: msg.payload,
                target: props.target,
            };
            (0, util_1.postRequest)(RED, this, msg, json);
        });
    }
    RED.nodes.registerType("volume-get", RedMobileVolumeGetNode);
    function validateVolume(volume) {
        return volume >= 0 && volume <= 100;
    }
    function RedMobileVolumeSetNode(props) {
        RED.nodes.createNode(this, props);
        this.on("input", (msg) => {
            if (props.volume === -1) {
                if (msg.payload !== undefined &&
                    typeof msg.payload === "number" &&
                    validateVolume(msg.payload)) {
                    props.volume = msg.payload;
                }
                else {
                    this.error(RED._("volume.errors.volume"));
                    this.status({
                        fill: "red",
                        shape: "ring",
                        text: RED._("volume.errors.volume"),
                    });
                    return;
                }
            }
            const json = {
                id: this.id,
                method: "volume-set",
                payload: msg.payload,
                volume: props.volume,
                target: props.target,
            };
            (0, util_1.postRequest)(RED, this, msg, json);
        });
    }
    RED.nodes.registerType("volume-set", RedMobileVolumeSetNode);
};
